function fid = dat_GEMSTONE_CLIPCOSY_imaging(spin_system,parameters,H,R,K,G,F)
%
% GEMSTONE experiment in the imaging context.
%
% ------------------------------------------------------------------------
% Daniel A. Taylor     Last modified: 2023/01/18
% ------------------------------------------------------------------------

% Check consistency
% grumble(spin_system,parameters,H,R,K)

% Deal with 'imaging' or 'liquid' contexts (i.e. ZS or BS experiment)
if strcmp(parameters.context, 'imaging')    
    % Compose Liouvillian    
    L = H + F + (1i*R) + (1i*K);    
    % Initial and detection states (defined in fidgen)
    rho0 = parameters.rho0;             
    coil = parameters.coil;
else    
    error('The GEMSTONE imaging experiment requires the imaging context')
end

% Define pulse operator
Lp = operator(spin_system,'L+',parameters.spins{1});
Lx = kron(speye(prod(parameters.npts)),(Lp+Lp')/2);
Ly = kron(speye(prod(parameters.npts)),(Lp-Lp')/2i);

% Coherent evolution timestep
timestep = 1/parameters.sweep;

% Get the chirp pulse waveform
[Cx,Cy] = chirp_pulse_xy(parameters.pulsenpoints,parameters.duration,...
                         parameters.bandwidth,parameters.smfactor,...
                         parameters.chirptype);

% Calculate RF amplitude
q_chirp = -(2*log(cosd(179.98)/2+1/2))/pi;
rfchirp = sqrt(parameters.duration*parameters.bandwidth*q_chirp/(2*pi))/(parameters.duration);

% Calibrate chirps
norm_factor = max(Cx); 
Cx = Cx/norm_factor; Cy = Cy/norm_factor;
Cx = 2*pi*rfchirp*Cx; Cy = 2*pi*rfchirp*Cy;
durations = ones(size(Cx))*parameters.duration/numel(Cx);

% Get rSNOB wave form
[C2x,C2y,durations2,Lshape] = hf_define_shape(spin_system,parameters,L,G);


% PULSE SEQUENCE ---------------------------------------------------------

% Apply the first pulse
rho_stack = step(spin_system,Lx,rho0,pi/2);

% Select "+1" coherence
rho_stack = coherence(spin_system,rho_stack,{{'1H',+1}});

% Apply 1st chirp pulse 
rho_stack = shaped_pulse_xy(spin_system,L+parameters.g_amp*G{1},{Lx,Ly},{Cx,+Cy},durations,rho_stack);

% Select "-1" coherence
rho_stack = coherence(spin_system,rho_stack,{{'1H',-1}});

% Apply the rSNOB pulse
rho_stack = shaped_pulse_xy(spin_system,Lshape,{Lx,Ly},{C2x,C2y},durations2,rho_stack);

% Select "+1" coherence
rho_stack = coherence(spin_system,rho_stack,{{'1H',+1}});

% Apply 2nd chirp pulse
rho_stack = shaped_pulse_xy(spin_system,L-parameters.g_amp*G{1},{Lx,Ly},{Cx,-Cy},durations,rho_stack);

% Select "-1" coherence
rho_stack = coherence(spin_system,rho_stack,{{'1H',-1}});

% Apply first 90 pulse of CLIP-COSY element
rho_stack = step(spin_system,Lx,rho_stack,pi/2);

% Zero-quantum suppression
rho_stack = homospoil(spin_system,rho_stack,'destroy');

% Apply second 90 pulse of CLIP-COSY element
rho_stack = step(spin_system,Lx,rho_stack,pi/2);

% Evolve for COSY mixing time
rho_stack = evolution(spin_system,L,[],rho_stack,parameters.tau_mix,1,'final');

% Apply first 180 pulse of COSY element
rho_stack = step(spin_system,Ly,rho_stack,pi);

% Evolve for COSY mixing time
rho_stack = evolution(spin_system,L,[],rho_stack,parameters.tau_mix,1,'final');

% Apply third 90 pulse
rho_stack = step(spin_system,Ly,rho_stack,pi/2);

% Evolve for COSY mixing time
rho_stack = evolution(spin_system,L,[],rho_stack,parameters.tau_mix,1,'final');

% Apply second 180 pulse of COSY element
rho_stack = step(spin_system,-Ly,rho_stack,pi);

% Evolve for COSY mixing time
rho_stack = evolution(spin_system,L,[],rho_stack,parameters.tau_mix,1,'final');

% Apply fourth 90 pulse of CLIP-COSY element
rho_stack = step(spin_system,Lx,rho_stack,pi/2);

% Zero-quantum suppression
rho_stack = homospoil(spin_system,rho_stack,'destroy');

% Apply fifth 90 pulse of CLIP-COSY element
rho_stack = step(spin_system,Lx,rho_stack,pi/2);

% Run the F2 evolution
fid = evolution(spin_system,L,coil,rho_stack,timestep,parameters.npoints-1,'observable');


end







% Simulation ID: 230117-161420
