function fid = dat_sel_CLIPCOSY(spin_system,parameters,H,R,K,G,F)
%
% Selective CLIP-COSY experiment.
%
% ------------------------------------------------------------------------
% Daniel A. Taylor    Last modified: 2023/01/18
% ------------------------------------------------------------------------


%% CHECK PARAMETERS ------------------------------------------------------

% parameters = fnc_check(parameters,spin_system);


%% DEFINITIONS -----------------------------------------------------------

% Deal with 'imaging' or 'liquid' contexts (i.e. ZS or BS experiment)
if strcmp(parameters.context, 'imaging')    
    % Compose Liouvillian    
    L = H + F + (1i*R) + (1i*K);    
    % Initial and detection states (defined in fidgen)
    rho0 = parameters.rho0;             
    coil = parameters.coil;
else    
    % Compose Liouvillian     
    L = H + (1i*R) + (1i*K);    
    % Initial and detection states    
    rho0 = state(spin_system,'Lz',parameters.spins{1});    
    coil = state(spin_system,'L+',parameters.spins{1});    
    % Define G to avoid unknown variable error
    G = {0};    
end

% Coherent evolution timesteps
timestep = 1/parameters.sweep;

% Define pulse operators
Lp = operator(spin_system,'L+',parameters.spins{1});
Lx = (Lp+Lp')/2;
Ly = (Lp-Lp')/2i;

% Define shaped pulses
[Cx,Cy,durations,Lshape] = hf_define_shape(spin_system,parameters,L,G);


%% PULSE SEQUENCE --------------------------------------------------------

% Apply the first pulse
rho = step(spin_system,Lx,rho0,pi/2);

% Select "+1" coherence
rho = coherence(spin_system,rho,{{'1H',+1}});
                
% Evolve for the delta period
rho = evolution(spin_system,L,[],rho,parameters.delta,1,'final');

% Apply the rSNOB pulse
rho = shaped_pulse_xy(spin_system,Lshape,{Lx,Ly},{Cx,Cy},durations,rho);

% Evolve for the delta period
rho = evolution(spin_system,L,[],rho,parameters.delta,1,'final');

% Select "-1" coherence
rho = coherence(spin_system,rho,{{'1H',-1}});

% Apply first 90 pulse of CLIP-COSY element
rho = step(spin_system,Lx,rho,pi/2);

% Zero-quantum suppression
rho = homospoil(spin_system,rho,'destroy');

% Apply second 90 pulse of CLIP-COSY element
rho = step(spin_system,Lx,rho,pi/2);
              
% Evolve for COSY mixing time
rho = evolution(spin_system,L,[],rho,parameters.tau_mix,1,'final');

% Apply first 180 pulse of COSY element
rho = step(spin_system,Ly,rho,pi);

% Evolve for COSY mixing time
rho = evolution(spin_system,L,[],rho,parameters.tau_mix,1,'final');
                              
% Apply third 90 pulse
rho = step(spin_system,Ly,rho,pi/2);

% Evolve for COSY mixing time
rho = evolution(spin_system,L,[],rho,parameters.tau_mix,1,'final');

% Apply second 180 pulse of COSY element
rho = step(spin_system,-Ly,rho,pi);

% Evolve for COSY mixing time
rho = evolution(spin_system,L,[],rho,parameters.tau_mix,1,'final');

% Apply fourth 90 pulse of CLIP-COSY element
rho = step(spin_system,Lx,rho,pi/2);

% Zero-quantum suppression
rho = homospoil(spin_system,rho,'destroy');

% Apply fifth 90 pulse of CLIP-COSY element
rho = step(spin_system,Lx,rho,pi/2);

% Run the F2 evolution
fid = evolution(spin_system,L,coil,rho,timestep,parameters.npoints-1,'observable');



end



% Simulation ID: 221208-192828
